#!/usr/bin/env python2

from distutils.core import setup

setup(name='smoff', version='0.0.2', description='Wicket-inspired template engine for python/django', author='Michael Donaghy', author_email='michael@optimalsocial.com', url='https://bitbucket.org/lmm/smoff', packages=['smoff'], package_dir = {'': 'src'})
